@@ -42,7 +42,7 @@ the secrets dictionary must contain 'ssid' and 'password' at a minimum
 in order to use network related features"""
     )
 
-__version__ = "1.14.2"
+__version__ = "1.14.4"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PortalBase.git"
 
 # pylint: disable=line-too-long, too-many-lines
@@ -72,6 +72,13 @@ CONTENT_IMAGE = const(3)
 class HttpError(Exception):
     """HTTP Specific Error"""
 
+    def __init__(self, message="", response=None):
+        if message != "":
+            super().__init__(message)
+        else:
+            super().__init__()
+        self.response = response
+
 
 class NetworkBase:
     """Network Base Class for the Portal-style libraries.
@@ -102,21 +109,7 @@ class NetworkBase:
             self._secrets = secrets_data
         else:
             self._secrets = secrets
-
-        if "networks" in self._secrets:
-            if isinstance(self._secrets["networks"], (list, tuple)):
-                self._secrets_network = self._secrets["networks"]
-            else:
-                raise TypeError(
-                    "'networks' must be a list/tuple of dicts of 'ssid' and 'password'"
-                )
-        else:
-            self._secrets_network = [
-                {
-                    "ssid": self._secrets["ssid"],
-                    "password": self._secrets["password"],
-                }
-            ]
+        self._secrets_network = None
 
         self.requests = None
 
@@ -296,7 +289,8 @@ class NetworkBase:
             raise HttpError(
                 "Code {}: {}".format(
                     response.status_code, response.reason.decode("utf-8")
-                )
+                ),
+                response,
             )
 
         if self._debug:
@@ -341,6 +335,23 @@ class NetworkBase:
                              failing or use None to disable. Defaults to 10.
 
         """
+
+        if not self._secrets_network:
+            if "networks" in self._secrets:
+                if isinstance(self._secrets["networks"], (list, tuple)):
+                    self._secrets_network = self._secrets["networks"]
+                else:
+                    raise TypeError(
+                        "'networks' must be a list/tuple of dicts of 'ssid' and 'password'"
+                    )
+            else:
+                self._secrets_network = [
+                    {
+                        "ssid": self._secrets["ssid"],
+                        "password": self._secrets["password"],
+                    }
+                ]
+
         for secret_entry in self._secrets_network:
 
             self._wifi.neo_status(STATUS_CONNECTING)
@@ -551,7 +562,8 @@ class NetworkBase:
             raise HttpError(
                 "Code {}: {}".format(
                     response.status_code, response.reason.decode("utf-8")
-                )
+                ),
+                response,
             )
 
         return content_type
